@@ -12,6 +12,7 @@ class AlipayCommerceTransportParkingEnterinfoSyncModel(object):
         self._free_enter_minutes = None
         self._in_time = None
         self._is_encrypt_plate_no = None
+        self._need_charge = None
         self._open_id = None
         self._out_serial_no = None
         self._parking_id = None
@@ -48,6 +49,13 @@ class AlipayCommerceTransportParkingEnterinfoSyncModel(object):
     def is_encrypt_plate_no(self, value):
         self._is_encrypt_plate_no = value
     @property
+    def need_charge(self):
+        return self._need_charge
+
+    @need_charge.setter
+    def need_charge(self, value):
+        self._need_charge = value
+    @property
     def open_id(self):
         return self._open_id
 
@@ -113,6 +121,11 @@ class AlipayCommerceTransportParkingEnterinfoSyncModel(object):
                 params['is_encrypt_plate_no'] = self.is_encrypt_plate_no.to_alipay_dict()
             else:
                 params['is_encrypt_plate_no'] = self.is_encrypt_plate_no
+        if self.need_charge:
+            if hasattr(self.need_charge, 'to_alipay_dict'):
+                params['need_charge'] = self.need_charge.to_alipay_dict()
+            else:
+                params['need_charge'] = self.need_charge
         if self.open_id:
             if hasattr(self.open_id, 'to_alipay_dict'):
                 params['open_id'] = self.open_id.to_alipay_dict()
@@ -158,6 +171,8 @@ class AlipayCommerceTransportParkingEnterinfoSyncModel(object):
             o.in_time = d['in_time']
         if 'is_encrypt_plate_no' in d:
             o.is_encrypt_plate_no = d['is_encrypt_plate_no']
+        if 'need_charge' in d:
+            o.need_charge = d['need_charge']
         if 'open_id' in d:
             o.open_id = d['open_id']
         if 'out_serial_no' in d:
