@@ -9,6 +9,7 @@ class AlipayEbppIndustryNucleicremindSubscribeModifyModel(object):
 
     def __init__(self):
         self._city_code = None
+        self._open_id = None
         self._reminder_hour_list = None
         self._status = None
         self._user_id = None
@@ -21,6 +22,13 @@ class AlipayEbppIndustryNucleicremindSubscribeModifyModel(object):
     def city_code(self, value):
         self._city_code = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def reminder_hour_list(self):
         return self._reminder_hour_list
 
@@ -53,6 +61,11 @@ class AlipayEbppIndustryNucleicremindSubscribeModifyModel(object):
                 params['city_code'] = self.city_code.to_alipay_dict()
             else:
                 params['city_code'] = self.city_code
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.reminder_hour_list:
             if isinstance(self.reminder_hour_list, list):
                 for i in range(0, len(self.reminder_hour_list)):
@@ -82,6 +95,8 @@ class AlipayEbppIndustryNucleicremindSubscribeModifyModel(object):
         o = AlipayEbppIndustryNucleicremindSubscribeModifyModel()
         if 'city_code' in d:
             o.city_code = d['city_code']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'reminder_hour_list' in d:
             o.reminder_hour_list = d['reminder_hour_list']
         if 'status' in d:
