@@ -11,6 +11,7 @@ class AlipayFundAuthOrderFreezeModel(object):
         self._amount = None
         self._auth_code = None
         self._auth_code_type = None
+        self._business_params = None
         self._disable_pay_channels = None
         self._enable_pay_channels = None
         self._extra_param = None
@@ -50,6 +51,13 @@ class AlipayFundAuthOrderFreezeModel(object):
     def auth_code_type(self, value):
         self._auth_code_type = value
     @property
+    def business_params(self):
+        return self._business_params
+
+    @business_params.setter
+    def business_params(self, value):
+        self._business_params = value
+    @property
     def disable_pay_channels(self):
         return self._disable_pay_channels
 
@@ -180,6 +188,11 @@ class AlipayFundAuthOrderFreezeModel(object):
                 params['auth_code_type'] = self.auth_code_type.to_alipay_dict()
             else:
                 params['auth_code_type'] = self.auth_code_type
+        if self.business_params:
+            if hasattr(self.business_params, 'to_alipay_dict'):
+                params['business_params'] = self.business_params.to_alipay_dict()
+            else:
+                params['business_params'] = self.business_params
         if self.disable_pay_channels:
             if hasattr(self.disable_pay_channels, 'to_alipay_dict'):
                 params['disable_pay_channels'] = self.disable_pay_channels.to_alipay_dict()
@@ -273,6 +286,8 @@ class AlipayFundAuthOrderFreezeModel(object):
             o.auth_code = d['auth_code']
         if 'auth_code_type' in d:
             o.auth_code_type = d['auth_code_type']
+        if 'business_params' in d:
+            o.business_params = d['business_params']
         if 'disable_pay_channels' in d:
             o.disable_pay_channels = d['disable_pay_channels']
         if 'enable_pay_channels' in d:
