@@ -10,6 +10,7 @@ class AlipayMarketingActivityVoucherSendModel(object):
     def __init__(self):
         self._activity_id = None
         self._merchant_access_mode = None
+        self._open_id = None
         self._out_biz_no = None
         self._user_id = None
 
@@ -28,6 +29,13 @@ class AlipayMarketingActivityVoucherSendModel(object):
     def merchant_access_mode(self, value):
         self._merchant_access_mode = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def out_biz_no(self):
         return self._out_biz_no
 
@@ -55,6 +63,11 @@ class AlipayMarketingActivityVoucherSendModel(object):
                 params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
             else:
                 params['merchant_access_mode'] = self.merchant_access_mode
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.out_biz_no:
             if hasattr(self.out_biz_no, 'to_alipay_dict'):
                 params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
@@ -76,6 +89,8 @@ class AlipayMarketingActivityVoucherSendModel(object):
             o.activity_id = d['activity_id']
         if 'merchant_access_mode' in d:
             o.merchant_access_mode = d['merchant_access_mode']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'out_biz_no' in d:
             o.out_biz_no = d['out_biz_no']
         if 'user_id' in d:
